==> php82-nextcloud-28.0.6.tgz: share/nextcloud/apps/firstrunwizard/l10n/ast.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Encontu pa la primer execución",
    "Add your profile information! For example your email is needed to receive notifications." : "¡Amiesta la información al to perfil! Por exemplu, la direición de corréu electrónicu ye necesariu pa recibir avisos.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "¡Amiesta la información al to perfil! Por exemplu, la direición de corréu electrónicu ye necesariu pa recibir avisos y renaiciar la contraseña",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Amiesta la información al to perfil! Afita una semeya pal perfil y amiesta'l to nome completu pa facilitar el reconocimientu en toles partes.",
    "Add your profile information! Set a full name for easier recognition across all features." : "¡Amiesta la información al to perfil! Amiesta'l to nome completu pa facilitar el reconocimientu en toles partes.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "¡Amiesta la información al to perfil! Afita una semeya pa facilitar el reconocimientu en toles partes.",
    "App recommendation: Nextcloud Calendar" : "Aplicación aconseyada: Calendariu",
    "Schedule work & meetings, synced with all your devices." : "Planifica'l trabayu y les reuniones con sincronización colos tos preseos.",
    "App recommendation: Nextcloud Contacts" : "Aplicación aconseyada: Contautos",
    "Keep your colleagues and friends in one place without leaking their private info." : "Ten a colegues y amigos nun llugar ensin revelar la so información personal",
    "App recommendation: Nextcloud Mail" : "Aplicación aconseyada: Corréu",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Una aplicación de corréu electrónicu cenciella que s'integra bien con Ficheros, Contautos y Calendariu.",
    "App recommendation: Tasks" : "Aplicación aconseyada: Xeres",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sincroniza les xeres de dellos preseos con Nextcloud y edítales en llinia.",
    "Kanban style organization for personal planning and team projects." : "Organización d'estilu kanban pa la planificación personal y proyeutos n'equipu.",
    "App recommendation: Forms" : "Aplicación aconseyada: Formularios",
    "Simple surveys and questionnaires, self-hosted" : "Encuestes y cuestionarios simples, autoagospiaos",
    "App recommendation: Recognize" : "Recomendación d'aplicación: Reconocimientu",
    "About & What's new" : "Tocante a y novedaes",
    "Download on Apple app store" : "Baxar na tienda d'aplicaciones d'Apple",
    "Download on Google play store" : "Baxar na tienda de Google Play",
    "Go to previous page" : "Dir a la páxina anterior",
    "Close" : "Zarrar",
    "More about Nextcloud" : "Más información tocante a Nextcloud",
    "Explore more apps ↗" : "Exokirar más aplicaciones ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Aumenta les funciones de Nextcloud con cientos d'aplicaciones desendolcaes pola comunidá.",
    "Get involved! ↗" : "¡Andecha! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "¡Forma parte de la comunidá qu'ayuda a crear, diseñar, traducir y dar puxu a Nextcloud!",
    "Need help? ↗" : "¿Precises ayuda? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Atopa más información tocante a la configuración de Nextcloud cola documentación p'alministradores, usuarios o desendolcadores.",
    "For large organisations ↗" : "Pa organizaciones más grandes ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Consiguir Nextcloud Enterprise pa entornos críticos onde la seguranza y conformidá avanzaes son importantes.",
    "This Nextcloud is on version {version}" : "Esta instancia de Nextcloud ta na versión {version}",
    "Seamless integration with your devices." : "Integración cenciella con tolos preseos de to.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Sincroniza ficheros ente los tos preseos coles aplicaciones pa ordenadores y móviles, y conecta'l calendariu y los contautos.",
    "Desktop app ↗" : "Aplicación pa ordenadores",
    "Calendar and contacts ↗" : "Calendariu y contautos ↗",
    "Connect your calendar and contacts with your devices." : "Conecta'l calendariu y los contautos colos tos preseos.",
    "Introducing Nextcloud Hub {version}" : "Presentación de Nextcloud Hub {version}",
    "Welcome to {cloudName}!" : "¡Afáyate en {cloudName}!",
    "A collaboration platform that puts you in control" : "Una plataforma de collaboración que te da'l control",
    "Privacy" : "Privacidá",
    "Host your data and files where you decide." : "Agospia los tos datos onde decidas.",
    "Productivity" : "Productividá",
    "Collaborate and communicate across any platform." : "Collabora y comunícate ente cualesquier plataforma.",
    "Interoperability" : "Interoperabilidá",
    "Import and export anything you want with open standards." : "Importa y exporta tolos que quieras con estándares abiertos.",
    "Community" : "Comunidá",
    "Share via email" : "Compartir per corréu electrónicu",
    "New in Nextcloud Hub {version}" : "Novedaes de Nextcloud Hub {version}",
    "What's new?" : "Novedaes",
    "Nextcloud on all your devices" : "Nextcloud en tolos preseos",
    "Read more" : "Lleer más",
    "Share on social media" : "Compartir el redes sociales",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "«%s» date accesu a los tos ficheros onde seya. Los nuesos veceros pa ordenadores y móviles, fáciles d'usar, tán disponibles de baldre pa les plataformes principales.",
    "Desktop client" : "Veceru pa ordenadores",
    "Android app on Google Play Store" : "Aplicación p'Android en Google Play Store",
    "Android app on F-Droid" : "Aplicación p'Android en F-Droid",
    "iOS app" : "Aplicación pa iOS",
    "Connect your calendar" : "Conectar el calendariu",
    "Connect your contacts" : "Conectar los contautos",
    "Access files via WebDAV" : "Acceder a los ficheros per WebDAV",
    "Server address" : "Direición del sirvidor",
    "Use this link to connect your apps and desktop client to this server:" : "Usa esti enllaz pa conectar les aplicaciones a esti sirvidor",
    "Copy link" : "Copiar l'enllaz",
    "Copied!" : "¡Copióse!",
    "Not supported!" : "¡Nun ye compatible!",
    "Press ⌘-C to copy." : "Primi ⌘-C pa copiar.",
    "Press Ctrl-C to copy." : "Primi Ctrl-C pa copiar.",
    "About" : "Tocante a",
    "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "Atopa más de 100 aplicaciones na tienda d'aplicaciones de Nextcloud pa personalizar la to nube:",
    "Communication with Nextcloud Talk" : "Comunicación con Nextcloud Talk",
    "Collaboration apps for document editing" : "Aplicación de collaboración pa la edición de documentos",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud date accesu a los tos ficheros onde seya.",
    "Get help" : "Consiguir ayuda",
    "Start contributing" : "Comenzar a collaborar",
    "Become part of the Community" : "Ser parte de la comunidá",
    "If you run Nextcloud in a mission critical environment where security and compliance are important, you need the certainty of Nextcloud Enterprise." : "Si executes Nextcloud nun entornu críticu onde la seguranza y conformidá con importantes, precises la seguranza de Nextcloud Enterprise.",
    "Learn more about Nextcloud Enterprise" : "Conoz más tocante a Nextcloud Enterprise",
    "Get more information" : "Más información",
    "The Nextcloud documentation for home users:" : "La documentación de Nextcloud pa usuarios domésticos:",
    "User manual" : "Manual pa usuarios",
    "Admin manual" : "Manual p'alministradores",
    "Developer manual" : "Manual pa desendolcadores",
    "You can also ask for help in our community support channels:" : "Tamién pues pidir ayuda nos canales d'apoyu de la nuesa comunidá:",
    "the Nextcloud forums" : "los foros de Nextcloud",
    "A safe home for all your data" : "Un llugar seguru pa los datos personales",
    "Host your data and files where you decide" : "Agospia datos y ficheros onde decidas",
    "Open standards and interoperability" : "Estándares abiertos ya interoperabilidá",
    "100%% open source & community-focused" : "100%% de códigu abiertu y enfocáu na comunidá",
    "Learn more about %s" : "Conoz más tocante a %s",
    "This Nextcloud is on version %s" : "Esta instancia de Nextcloud ta na versión %s",
    "Close dialog" : "Zarrar el diálogu",
    "This Nextcloud is on version " : "Esta instancia de Nextcloud ta na versión"
},
"nplurals=2; plural=(n != 1);");

==> php82-nextcloud-29.0.7.tgz: share/nextcloud/apps/firstrunwizard/l10n/ast.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Encontu pa la primer execución",
    "Add your profile information! For example your email is needed to receive notifications." : "¡Amiesta la información al to perfil! Por exemplu, la direición de corréu electrónicu ye necesariu pa recibir avisos.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "¡Amiesta la información al to perfil! Por exemplu, la direición de corréu electrónicu ye necesariu pa recibir avisos y renaiciar la contraseña",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "¡Amiesta la información al to perfil! Afita una semeya pal perfil y amiesta'l to nome completu pa facilitar el reconocimientu en toles partes.",
    "Add your profile information! Set a full name for easier recognition across all features." : "¡Amiesta la información al to perfil! Amiesta'l to nome completu pa facilitar el reconocimientu en toles partes.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "¡Amiesta la información al to perfil! Afita una semeya pa facilitar el reconocimientu en toles partes.",
    "App recommendation: Nextcloud Calendar" : "Aplicación aconseyada: Calendariu",
    "Schedule work & meetings, synced with all your devices." : "Planifica'l trabayu y les reuniones con sincronización colos tos preseos.",
    "App recommendation: Nextcloud Contacts" : "Aplicación aconseyada: Contautos",
    "Keep your colleagues and friends in one place without leaking their private info." : "Ten a colegues y amigos nun llugar ensin revelar la so información personal",
    "App recommendation: Nextcloud Mail" : "Aplicación aconseyada: Corréu",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Una aplicación de corréu electrónicu cenciella que s'integra bien con Ficheros, Contautos y Calendariu.",
    "App recommendation: Tasks" : "Aplicación aconseyada: Xeres",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Sincroniza les xeres de dellos preseos con Nextcloud y edítales en llinia.",
    "Kanban style organization for personal planning and team projects." : "Organización d'estilu kanban pa la planificación personal y proyeutos n'equipu.",
    "App recommendation: Forms" : "Aplicación aconseyada: Formularios",
    "Simple surveys and questionnaires, self-hosted" : "Encuestes y cuestionarios simples, autoagospiaos",
    "App recommendation: Recognize" : "Recomendación d'aplicación: Reconocimientu",
    "Connect your calendar" : "Conectar el calendariu",
    "Connect your contacts" : "Conectar los contautos",
    "Access files via WebDAV" : "Acceder a los ficheros per WebDAV",
    "Desktop client" : "Veceru pa ordenadores",
    "Android app on Google Play Store" : "Aplicación p'Android en Google Play Store",
    "Android app on F-Droid" : "Aplicación p'Android en F-Droid",
    "iOS app" : "Aplicación pa iOS",
    "About & What's new" : "Tocante a y novedaes",
    "Download on Apple app store" : "Baxar na tienda d'aplicaciones d'Apple",
    "Download on Google play store" : "Baxar na tienda de Google Play",
    "Go to previous page" : "Dir a la páxina anterior",
    "Close" : "Zarrar",
    "More about Nextcloud" : "Más información tocante a Nextcloud",
    "Explore more apps ↗" : "Esplora más aplicaciones ↗",
    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "Aumenta les funciones de Nextcloud con cientos d'aplicaciones desendolcaes pola comunidá.",
    "Get involved! ↗" : "¡Andecha! ↗",
    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "¡Forma parte de la comunidá qu'ayuda a crear, diseñar, traducir y dar puxu a Nextcloud!",
    "Need help? ↗" : "¿Precises ayuda? ↗",
    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "Atopa más información tocante a la configuración de Nextcloud cola documentación p'alministradores, usuarios o desendolcadores.",
    "For large organisations ↗" : "Pa organizaciones más grandes ↗",
    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "Consiguir Nextcloud Enterprise pa entornos críticos onde la seguranza y conformidá avanzaes son importantes.",
    "Seamless integration with your devices." : "Integración cenciella con tolos preseos de to.",
    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "Sincroniza ficheros ente los tos preseos coles aplicaciones pa ordenadores y móviles, y conecta'l calendariu y los contautos.",
    "Desktop app ↗" : "Aplicación pa ordenadores",
    "Calendar and contacts ↗" : "Calendariu y contautos ↗",
    "Connect your calendar and contacts with your devices." : "Conecta'l calendariu y los contautos colos tos preseos.",
    "Introducing Nextcloud Hub {version}" : "Presentación de Nextcloud Hub {version}",
    "Welcome to {cloudName}!" : "¡Afáyate en {cloudName}!",
    "A collaboration platform that puts you in control" : "Una plataforma de collaboración que te da'l control",
    "Privacy" : "Privacidá",
    "Host your data and files where you decide." : "Agospia los tos datos onde decidas.",
    "Productivity" : "Productividá",
    "Collaborate and communicate across any platform." : "Collabora y comunícate ente cualesquier plataforma.",
    "Interoperability" : "Interoperabilidá",
    "Import and export anything you want with open standards." : "Importa y exporta tolos que quieras con estándares abiertos.",
    "Community" : "Comunidá",
    "Enjoy constant improvements from a thriving open-source community." : "Esfruta les meyores continues d'una comunidá de códigu abiertu esitosa.",
    "This Nextcloud is on version {version}" : "Esta instancia de Nextcloud ta na versión {version}",
    "Share via email" : "Compartir per corréu electrónicu",
    "New in Nextcloud Hub {version}" : "Novedaes de Nextcloud Hub {version}",
    "Server address" : "Direición del sirvidor",
    "Use this link to connect your apps and desktop client to this server:" : "Usa esti enllaz pa conectar les aplicaciones a esti sirvidor",
    "What's new?" : "Novedaes",
    "Nextcloud on all your devices" : "Nextcloud en tolos preseos",
    "Read more" : "Lleer más",
    "Share on social media" : "Compartir el redes sociales",
    "Copied!" : "¡Copióse!",
    "Not supported!" : "¡Nun ye compatible!",
    "Press ⌘-C to copy." : "Primi ⌘-C pa copiar.",
    "Press Ctrl-C to copy." : "Primi Ctrl-C pa copiar.",
    "About" : "Tocante a",
    "Close dialog" : "Zarrar el diálogu",
    "This Nextcloud is on version " : "Esta instancia de Nextcloud ta na versión",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "«%s» date accesu a los tos ficheros onde seya. Los nuesos veceros pa ordenadores y móviles, fáciles d'usar, tán disponibles de baldre pa les plataformes principales.",
    "Copy link" : "Copiar l'enllaz"
},
"nplurals=2; plural=(n != 1);");
